@@ -1,14 +1,14 @@
+from trashcli.empty.clock import Clock
 from trashcli.empty.older_than import older_than
-from trashcli.trash import Clock, parse_deletion_date
-
-
-class ContentReader:
-    def contents_of(self, path):
-        raise NotImplementedError
+from trashcli.fs import ContentsOf
+from trashcli.parse_trashinfo.parse_deletion_date import parse_deletion_date
 
 
 class DeleteAccordingDate:
-    def __init__(self, reader, clock):  # type: (ContentReader, Clock) -> None
+    def __init__(self,
+                 reader,  # type: ContentsOf
+                 clock,  # type: Clock
+                 ):
         self.reader = reader
         self.clock = clock
 
